from django import template
from ..context import VueContext
from ..settings import get_setting

register = template.Library()

script_name = 'script_vue3.html' if get_setting('VUE_VERSION', '2') == '3' else 'script.html'


@register.inclusion_tag(script_name, name='vue')
def vue(vue_ctx):
    if not isinstance(vue_ctx, VueContext):
        raise TypeError("Argument to 'vue' template must be a VueContext")

    return vue_ctx._to_render()



from os.path import join
from .settings import get_setting


class VueContext():

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.data = {}
        self.scripts = []
        # TODO: make this a setting
        self.static_base = join('build', 'js')

    def set_data(self, key, val):
        """ Sets some data to be served to the Vue app """
        self.data[key] = val

    def add_script(self, script_loc):
        """ Add a static JS script to include in the page as well """
        self.scripts.append(script_loc)

    def _to_render(self):
        """ Return a dictionary to use to render the template """
        script_suffix = '.umd.min.js' if self._use_minified() else '.umd.js'
        obj = {
            'data': self.data,
            'use_minified': self._use_minified(),
            'scripts': self.scripts,
            'script_locs': [
                join(
                    self.static_base,
                    sc + script_suffix
                ) for sc in self.scripts
            ],
        }
        return obj

    def _use_minified(self):
        return any([
            get_setting('USE_MINIFIED', False),
            get_setting('ENV', prefix=False) == 'prod',
            get_setting('ENVIRONMENT', prefix=False) == 'prod',
            get_setting('ENV', prefix=False) == 'production',
            get_setting('ENVIRONMENT', prefix=False) == 'production',
        ])



SETTINGS_PREFIX = "POINT_OF_VUE_"


def get_setting(value, default=None, prefix=True):
    try:
        from django.conf import settings
    except ImportError:
        return default

    if prefix:
        value = SETTINGS_PREFIX + value

    return getattr(settings, value, default)



import re
import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

with open('requirements.txt') as f:
    reqs = f.read().splitlines()

with open('pointofvue/__init__.py', 'r') as fd:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
                        fd.read(), re.MULTILINE).group(1)


setuptools.setup(
    name="pointofvue",
    version=version,
    author="Matt Dodge",
    author_email="mattedgod@gmail.com",
    description="A simple, opinionated way to incorporate VueJS into Django apps",
    long_description=long_description,
    long_description_content_type="text/markdown",
    install_requires=reqs,
    include_package_data=True,
    url="https://github.com/mattdodge/PointOfVue",
    packages=setuptools.find_packages(),
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Environment :: Web Environment",
        "Framework :: Django",
        "Framework :: Django :: 2.2",
        "Intended Audience :: Developers",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
    ],
)
